@@ -662,8 +662,7 @@ class Import_session(object):
             try:
                 content = STATS[self._id]['actual_line'][column]
             except IndexError:
-                raise exceptions.ColumnIndexError(model,
-                        'Invalid column index `%s`' % column, self._logger)
+                raise exceptions.ColumnIndexError(model, None, None, column, logger=self._logger)
         else:
             content = callback
         return content
@@ -766,7 +765,11 @@ class Import_session(object):
                     try:
                         search_rel = self._convert(line, model, data_rel)
                     except exceptions.SkipObjectException:
-                        self._logger.info("<%-20s> Object skipped" % model, extra=STATS[self._id])
+                        print "################################################### SKIPPED #################################################################"
+                        try:
+                            model = model.split('::')[1]
+                        except:
+                            pass
                         STATS['objects'][model]['skipped'] += 1
                         STATS[self._id]['object_skipped'] += 1
                         return False
@@ -806,7 +809,9 @@ class Import_session(object):
                     returned_value = self._get_callback(line, model, callback,
                             key, content)
                     if returned_value is compare_value:
-                        raise exceptions.SkipObjectException('%s is required' % key.split('::')[1])
+                        raise exceptions.SkipObjectException(
+                                model, key.split('::')[1], content, line,
+                                logger=self._logger)
                     
                     # rename key becomed unusefull
                     data[key.split('::')[1]] = data[key]
@@ -821,7 +826,9 @@ class Import_session(object):
                         self._logger.debug('<%-25s> processing %s=%s' % (model,
                             key, content), extra=STATS[self._id])
                     else:
-                        raise exceptions.SkipLineException(model)
+                        raise exceptions.SkipLineException(
+                                model, key.split('::')[1], content, line,
+                                logger=self._logger)
 
 
     def _replace_line(self, line, data, model):
@@ -875,7 +882,9 @@ class Import_session(object):
                     returned_value = self._get_callback(line, model, callback,
                             key, content)
                     if returned_value:
-                        raise exceptions.SkipObjectException(model)
+                        raise exceptions.SkipObjectException(
+                                model, key.split('::')[1], content, line,
+                                logger=self._logger)
                     else:
                         # Finally remove key unusefull and create new one with
                         # correct tuple without callback
@@ -897,7 +906,9 @@ class Import_session(object):
                     returned_value = self._get_callback(line, model, callback,
                             key, content)
                     if returned_value:
-                        raise exceptions.SkipObjectException(model)
+                        raise exceptions.SkipObjectException(
+                                model, key.split('::')[1], content, line,
+                                logger=self._logger)
                     else:
                         # Finally remove key unusefull and create new one with
                         # correct tuple without callback
@@ -1104,13 +1115,13 @@ formed, \n\n" % (model, attr)
         state = 'old'
 
         # Manage null values
-        for attr, value in data.items():
-            try:
-                data[attr] = value.strip(' \t\n\r\r\n')
-            except:
-                pass
-            if not data[attr]:
-                del data[attr]
+        #for attr, value in data.items():
+            #try:
+            #    data[attr] = value.strip(' \t\n\r\r\n')
+            #except:
+            #    pass
+            #if data[attr] == "":
+            #    del data[attr]
 
         search = self._search(model, data, search)
 
@@ -1150,6 +1161,11 @@ formed, \n\n" % (model, attr)
                                 self._name_get(model, data=data)),
                                 extra=STATS[self._id])
 
+                    elif len(search) > 1:
+                        self._logger.warning("<%-25s> MULTIPLE SEARCH RESULT, detail your search options %s"% (model, res),
+                               extra=STATS[self._id])
+                        res = [False]
+
                     else:
                         state = 'old'
                         res = search
@@ -1204,7 +1220,6 @@ formed, \n\n" % (model, attr)
             search = self._convert(line, model, self.mapping[model])
             self._columns_mapping[model]['search'] = search
         except exceptions.SkipObjectException:
-            self._logger.info("<%-20s> Object skipped" % model, extra=STATS[self._id])
             STATS['objects'][model]['skipped'] += 1
             STATS[self._id]['object_skipped'] += 1
             return False
@@ -1346,7 +1361,7 @@ formed, \n\n" % (model, attr)
                     STATS[self._id]['error'] += 1
                     self._logger.error('callback must be a function',
                             extra=STATS[self._id])
-                    raise exceptions.SkipLineException()
+                    raise exceptions.SkipLineException(model, None, None, line)
 
                 # If result is a relation, so launch relation creation function
                 if isinstance(content, str) and content.startswith("REL_"):
@@ -1360,7 +1375,7 @@ formed, \n\n" % (model, attr)
                 STATS[self._id]['error'] += 1
                 self._logger.error('callback is mandatory',
                         extra=STATS[self._id])
-                raise exceptions.SkipLineException()
+                raise exceptions.SkipLineException(model, None, None, line)
             #else:
             #    STATS[self._id]['error'] += 1
             #    self._logger.error('Callback or columns is mandatory.',
@@ -1379,16 +1394,16 @@ formed, \n\n" % (model, attr)
                 data[item] = content.strip(' \t\n\r\r\n')
             except:
                 data[item] = content
+
             #Cleaning dict items with null value
             if data[item] not in (0, '0') and not data[item]:
                 if required:
-                    raise exceptions.RequiredFieldError(
-                        '%s %s field is required. Skipped.' % (model, item))
-                ToRemove.append(item)
+                    raise exceptions.RequiredFieldError(model, item, data[item], line, logger=self._logger)
+                #ToRemove.append(item)
 
         # Cleaning data from given attributes
-        for item in ToRemove:
-            del data[item]
+        #for item in ToRemove:
+        #    del data[item]
         
         # Adding this to indicate that this field has been loaded
         data['CREATED::search'] = search
@@ -1411,17 +1426,15 @@ formed, \n\n" % (model, attr)
                     (state, model, id) = self._create(model,
                             data, search)
             
-            except exceptions.RequiredFieldError as error:
+            except exceptions.RequiredFieldError:
                 # Required field not found
                 continue
-            except exceptions.SkipObjectException as error:
-                self._logger.info("<%-20s> Object skipped" % model, extra=STATS[self._id])
+            except exceptions.SkipObjectException:
                 STATS['objects'][model]['skipped'] += 1
                 STATS[self._id]['object_skipped'] += 1
                 # Next object
                 continue
-            except exceptions.SkipLineException as error:
-                self._logger.info("<%-20s> Line skipped(%s)" % (model, error), extra=STATS[self._id])
+            except exceptions.SkipLineException:
                 STATS[self._id]['line_skipped'] += 1
                 # Next line
                 break 
