@@ -37,11 +37,11 @@ Exceptions used in csv2oerp.
 
 from constants_and_vars import STATS
 
-class RequiredFieldError(IndexError):
+class RequiredFieldError(BaseException):
     """Exception used when a column index has not be found 
     
     """
-    def __init__(self, model, field, log=None):
+    def __init__(self, model, field, value=None, line=None, logger=None):
         """
         :param model: Object model
         :type model: str
@@ -49,9 +49,13 @@ class RequiredFieldError(IndexError):
         :type field: str
 
         """
-        msg = "Required model(%s) field(%s) has null value. Skipping." % (model, field)
-        if log:
-            log.info("<%-20s> %s" % msg, extra=STATS)
+        if line is None:
+            msg = "Required field '%s' has null value ('%s') at line %s. Skipping."\
+                    % (model, field, value, line)
+        else:
+            msg = field
+        if logger:
+            logger.info("<%-20s> %s" % (model, msg), extra=STATS)
         super(RequiredFieldError, self).__init__(msg)
 
 
@@ -59,7 +63,7 @@ class ColumnIndexError(IndexError):
     """Exception used when a column index has not be found 
     
     """
-    def __init__(self, model, msg="", log=None):
+    def __init__(self, model, field=None, value=None, column=None, logger=None):
         """
         :param model: Object model
         :type model: str
@@ -67,8 +71,13 @@ class ColumnIndexError(IndexError):
         :type msg: str
 
         """
-        if log:
-            log.info("<%-20s> Invalid column index found" % model, extra=STATS)
+        if column is None:
+            msg = "Invalid column index found for field '%s'('%s') at column %s"\
+                    % (model, field, value, column)
+        else:
+            msg = field
+        if logger:
+            logger.info("<%-20s> %s" % (model, msg), extra=STATS)
         super(ColumnIndexError, self).__init__(msg)
 
 
@@ -76,8 +85,9 @@ class SkipLineException(BaseException):
     """Exception used when a subfunction need to skip a entire particular line
     
     Usefull into lambda statement with field definition
+
     """
-    def __init__(self, msg=""):
+    def __init__(self, model, field=None, value=None, line=None, logger=None):
         """
         :param model: Object model
         :type model: str
@@ -85,6 +95,13 @@ class SkipLineException(BaseException):
         :type msg: str
 
         """
+        if line is None:
+           msg = "Skipped line for field '%s'('%s') at line %s"\
+                % (model, field, value, line)
+        else:
+            msg = field
+        if logger:
+            logger.info("<%-20s> %s" % (model, msg), extra=STATS)
         super(SkipLineException, self).__init__(msg)
 
 
@@ -94,7 +111,7 @@ class SkipObjectException(BaseException):
     Usefull into lambda statement with field definition
 
     """
-    def __init__(self, msg=""):
+    def __init__(self, model, field=None, value=None, line=None, logger=None):
         """
         :param model: Object model
         :type model: str
@@ -102,5 +119,12 @@ class SkipObjectException(BaseException):
         :type msg: str
 
         """
+        if line is None:
+            msg = "Skipped object for field '%s'('%s') at line %s"\
+                    % (model, field, value, line)
+        else:
+            msg = field
+        if logger:
+            logger.info("<%-20s> %s" % (model, msg), extra=STATS)
         super(SkipObjectException, self).__init__(msg)
 
